kickin_storage library
A Kickin package providing simple helpers around Hive for app and secure storage.
Classes
-
AppHive<
T> - Simple helper around a Hive box for application-level storage.
-
KHive<
T> - Top-level helper to initialize and access app and secure Hive boxes.
-
KLazyHive<
T> - Simple helper around a Lazy Hive box for application-level storage.
-
KSecureHive<
T> -
A small wrapper around Hive that uses a platform secure storage-backed
encryption key (via
flutter_secure_storage) to provide encrypted boxes.
Constants
- kAppBoxName → const String
- kLazyBoxName → const String
- kSecureBoxName → const String